@@ -8,8 +8,11 @@ skip_tests() {
     if test "$SKIPPED_TESTS" != "force"
     then
         # Skip tests from ci/skipped_tests if this is the right OS version
-        # The file
-        os_id="$(sh -c '. /etc/os-release; echo "${NAME}-${VERSION_ID}"')"
+        if test -f /etc/os-release; then
+            os_id="$(sh -c '. /etc/os-release; echo "${NAME}-${VERSION_ID}"')"
+        else
+            os_id=`uname`
+        fi
 
         echo OS ID: $os_id
 
@@ -62,6 +65,15 @@ run_checks() {
     failed=0
     $MAKE "$@" || failed=1
     restore_tests
+    if [ "$failed" ]; then
+        for f in $(find . -name '*.log' |
+                       grep -v /test-suite.log |
+                       xargs grep -l FAIL ); do
+            echo
+            echo "==== $f ===="
+            cat $f
+        done
+    fi
     return $failed
 }
 
@@ -146,12 +158,6 @@ $CONFIG_ARGS
         return 0
     fi
 
-    if test "$(uname)" != "Linux"
-    then
-        echo "Tests are temporarily skipped on non-Linux platforms"
-        return 0
-    fi
-
     run_checks check
 
     # if test "$CHECK_VALGRIND" = "force"
